[?1034h

General configuration
| `check_params` | `False``` | If true, erases the cache if job parameters appear to change.
Storage setting backend
| `db` | `filesystem``` | Specifies db backend. XXX: so far, only 'filesystem' officially supported.
`path` | `compmake_storage``` | [filesystem] Path to directory for filesystem storage.
Appearance
| `echo_stdout` | `True``` | If true, the job output to stdout is shown.
`echo_stderr` | `True``` | If true, the job output to stderr is shown.
`colorize` | `True``` | Use colors in terminals if possible.
`verbose_definition` | `False``` | If true, log on stderr about job (re)definition.
Multiprocessing
| `max_mem_load` | `100.0``` | Maximum physical memory load (%)
`max_cpu_load` | `100.0``` | Maximum CPU load (%). No jobs will be instantiated if over threshold.
`autobal_after` | `8``` | Autobalances after the given number of processes (%)
`min_proc_interval` | `0``` | Minimum time interval between instantiating jobs.
Cluster execution
| `cluster_conf` | `cluster.yaml``` | Location of cluster configuration file.
`hostname` | `localhost``` | Nickname for current host (set by compmake master).
`cluster_nice` | `0``` | Nice level for spawned remote processes.
`cluster_show_cmd` | `True``` | If true, it shows the connection string to the slaves.